@@ -22,9 +22,7 @@ class TestCase(unittest.TestCase):
         remove_dir(self.root_dir)
 
     def test_alioss(self):
-        config = z.OssConfig(access_key_id="LTAI4Fr9r2aYm6nLxGGzfWU9", access_key_secret="alEzYCJdyqBHLIobHjFHkZXstvxMEn",
-                             bucket="data-3rd", endpoint="https://oss-cn-zhangjiakou.aliyuncs.com")
-        oss = z.OssFile(config)
+        oss = z.AliOss("oss://oss-cn-zhangjiakou.aliyuncs.com/data-3rd?key=LTAI4Fr9r2aYm6nLxGGzfWU9&secret=alEzYCJdyqBHLIobHjFHkZXstvxMEn")
         a_path = "setup.py"
         b_path = os.path.join(self.root_dir, "b.py")
         oss.upload("test/setup.py", a_path)
@@ -34,7 +32,7 @@ class TestCase(unittest.TestCase):
         self.assertEqual(a, b)
         
     def test_alioss_with_config_file(self):
-        oss = z.OssFile()
+        oss = z.AliOss("oss://oss-cn-zhangjiakou.aliyuncs.com/data-3rd?key=LTAI4Fr9r2aYm6nLxGGzfWU9&secret=alEzYCJdyqBHLIobHjFHkZXstvxMEn")
         a_path = "setup.py"
         b_path = os.path.join(self.root_dir, "b.py")
         oss.upload(key="test/setup1.py", file_path=a_path)
